Welcome to Jolt
===============

Jolt is an easy to use, yet powerful task execution tool. Tasks are defined
in Python scripts using a class based API. A task typically produces output
which can be published as binary artifacts into content addressable caches
for later consumption by other tasks.

Distributed execution and remote storage providers are supported through plugins.

For full documentation, please visit http://jolt.readthedocs.io/
